Filter

Enum Filter 

#[repr(i8)]
pub enum Filter { Transparent = 0, Opaque = 1, }
Represents a filter that can be either transparent or opaque.

NOTE: The behaviour of this type is value-dependant.

Variants



Transparent = 0

Allows values through.



Opaque = 1

Does not allow values through.

Implementations

Source

impl Filter

pub fn new<T>(target_cond: T) -> Self
where T: Into<bool>,

Creates a new Filter instance based on the target condition.

pub fn condition<T>(target_cond: bool) -> T
where T: Primitive, i8: Cast<T>,

Returns the condition as a generic type T.

pub fn mask<T>(self) -> T
where T: Primitive, i8: Cast<T>,

Returns the mask value as a generic type T.